# IncidentField

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**associated_to_all** | **bool** |  | [optional] 
**associated_types** | **list[str]** | AssociatedTypes - list of incident (case) types IDs related to specific incident field | [optional] 
**breach_script** | **str** |  | [optional] 
**case_insensitive** | **bool** |  | [optional] 
**cli_name** | **str** |  | [optional] 
**close_form** | **bool** |  | [optional] 
**columns** | [**list[GridColumn]**](GridColumn.md) |  | [optional] 
**commit_message** | **str** |  | [optional] 
**content** | **bool** |  | [optional] 
**default_rows** | **list[dict(str, object)]** |  | [optional] 
**description** | **str** |  | [optional] 
**edit_form** | **bool** |  | [optional] 
**field_calc_script** | **str** |  | [optional] 
**group** | [**FieldGroup**](FieldGroup.md) |  | [optional] 
**hidden** | **bool** |  | [optional] 
**id** | **str** |  | [optional] 
**is_read_only** | **bool** |  | [optional] 
**locked** | **bool** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**never_set_as_required** | **bool** |  | [optional] 
**owner_only** | **bool** |  | [optional] 
**placeholder** | **str** |  | [optional] 
**prev_name** | **str** |  | [optional] 
**required** | **bool** |  | [optional] 
**script** | **str** |  | [optional] 
**select_values** | **list[str]** |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**sla** | **int** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**system** | **bool** |  | [optional] 
**system_associated_types** | **list[str]** |  | [optional] 
**threshold** | **float** |  | [optional] 
**type** | **str** |  | [optional] 
**unmapped** | **bool** |  | [optional] 
**unsearchable** | **bool** |  | [optional] 
**use_as_kpi** | **bool** |  | [optional] 
**validated_error** | **str** |  | [optional] 
**validation_regex** | **str** |  | [optional] 
**vc_should_ignore** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


